.. include:: /_includes/wip_prolog.rst

:mod:`stix.common.vocabs` Module
==================================

.. module:: stix.common.vocabs

Classes
-------

.. autoclass:: VocabString
	:show-inheritance:
	:members:

.. autoclass:: AssetType
	:show-inheritance:
	:members:

.. autoclass:: AttackerInfrastructureType
	:show-inheritance:
	:members:

.. autoclass:: AttackerToolType
	:show-inheritance:
	:members:

.. autoclass:: AvailabilityLossType
	:show-inheritance:
	:members:

.. autoclass:: CampaignStatus
	:show-inheritance:
	:members:

.. autoclass:: COAStage
	:show-inheritance:
	:members:

.. autoclass:: CourseOfActionType
	:show-inheritance:
	:members:

.. autoclass:: DiscoveryMethod
	:show-inheritance:
	:members:

.. autoclass:: HighMediumLow
	:show-inheritance:
	:members:

.. autoclass:: ImpactQualification
	:show-inheritance:
	:members:

.. autoclass:: ImpactRating
	:show-inheritance:
	:members:

.. autoclass:: IncidentCategory
	:show-inheritance:
	:members:

.. autoclass:: IncidentEffect
	:show-inheritance:
	:members:

.. autoclass:: IncidentStatus
	:show-inheritance:
	:members:

.. autoclass:: IndicatorType
	:show-inheritance:
	:members:

.. autoclass:: InformationSourceRole
	:show-inheritance:
	:members:

.. autoclass:: InformationType
	:show-inheritance:
	:members:

.. autoclass:: IntendedEffect
	:show-inheritance:
	:members:

.. autoclass:: LocationClass
	:show-inheritance:
	:members:

.. autoclass:: LossDuration
	:show-inheritance:
	:members:

.. autoclass:: LossProperty
	:show-inheritance:
	:members:

.. autoclass:: MalwareType
	:show-inheritance:
	:members:

.. autoclass:: ManagementClass
	:show-inheritance:
	:members:

.. autoclass:: Motivation
	:show-inheritance:
	:members:

.. autoclass:: OwnershipClass
	:show-inheritance:
	:members:

.. autoclass:: PackageIntent
	:show-inheritance:
	:members:

.. autoclass:: PlanningAndOperationalSupport
	:show-inheritance:
	:members:

.. autoclass:: SecurityCompromise
	:show-inheritance:
	:members:

.. autoclass:: SystemType
	:show-inheritance:
	:members:

.. autoclass:: ThreatActorSophistication
	:show-inheritance:
	:members:

.. autoclass:: ThreatActorType
	:show-inheritance:
	:members:

Functions
---------

.. autofunction:: add_vocab

Constants
---------

.. autodata:: _VOCAB_MAP
